@@ -1,5 +1,9 @@
+pub mod graph;
+pub mod math;
+pub mod search;
 pub mod sort;
 pub mod subset;
+pub mod tree;
 
 #[cfg(test)]
 mod tests {
